![Commit Activity](https://img.shields.io/github/commit-activity/m/bitsy-ai/octoprint-nanny-plugin)
![Release](https://img.shields.io/github/release-date-pre/bitsy-ai/octoprint-nanny-plugin)
![Discord](https://img.shields.io/discord/773452324692688956)
![Github Followers](https://img.shields.io/github/followers/leigh-johnson?style=social)

![Tests](https://img.shields.io/github/workflow/status/bitsy-ai/octoprint-nanny-plugin/PyTest%20Coverage%20Report)
![Mypy Coverage](https://img.shields.io/codecov/c/github/bitsy-ai/octoprint-nanny-plugin?flag=mypy&label=mypy%20coverage)
![unittest Coverage](https://img.shields.io/codecov/c/github/bitsy-ai/octoprint-nanny-plugin?flag=unittest&label=unittest%20coverage)

![Print Nanny Logo](https://github.com/bitsy-ai/octoprint-nanny-plugin/raw/main/docs/images/logo.jpg)

OctoPrint monitoring & alerting AI.

## Getting Started

* [Request invitation to closed Beta](https://www.print-nanny.com/request-invite/)
* [OctoPrint Plugin setup](https://help.print-nanny.com/octoprint-plugin-setup/)

## Credits

Google supported this work by providing Google Cloud credit
